@@ -24,50 +24,53 @@
 #'@return 3-layer RGB array of the processed image.
 #'@export
 #'@examples
-#'if(rayimage:::run_documentation()){
+#'if(run_documentation()){
 #'#Perform a convolution with the default gaussian kernel
 #'plot_image(dragon)
 #'}
-#'if(rayimage:::run_documentation()){
+#'if(run_documentation()){
 #'#Perform a convolution with the default gaussian kernel
 #'render_convolution(dragon, preview = TRUE)
 #'}
-#'if(rayimage:::run_documentation()){
+#'if(run_documentation()){
 #'#Increase the width of the kernel
 #'render_convolution(dragon, kernel = 2, kernel_dim=21,kernel_extent=6, preview = TRUE)
 #'}
-#'if(rayimage:::run_documentation()){
+#'if(run_documentation()){
 #'#Perform edge detection using a edge detection kernel
 #'edge = matrix(c(-1,-1,-1,-1,8,-1,-1,-1,-1),3,3)
-#'render_convolution(dragon, kernel = edge, preview = TRUE, absolute=FALSE)
+#'render_convolution(render_bw(dragon), kernel = edge, preview = TRUE, absolute=FALSE)
 #'}
-#'if(rayimage:::run_documentation()){
+#'if(run_documentation()){
 #'#Perform edge detection with Sobel matrices
 #'sobel1 = matrix(c(1,2,1,0,0,0,-1,-2,-1),3,3)
 #'sobel2 = matrix(c(1,2,1,0,0,0,-1,-2,-1),3,3,byrow=TRUE)
-#'sob1 = render_convolution(dragon, kernel = sobel1)
-#'sob2 = render_convolution(dragon, kernel = sobel2)
+#'sob1 = render_convolution(render_bw(dragon), kernel = sobel1)
+#'sob2 = render_convolution(render_bw(dragon), kernel = sobel2)
 #'sob_all = sob1 + sob2
+#'plot_image(sob1)
+#'plot_image(sob2)
 #'plot_image(sob_all)
 #'}
-#'if(rayimage:::run_documentation()){
+#'
+#'if(run_documentation()){
 #'#Only perform the convolution on bright pixels (bloom)
 #'render_convolution(dragon, kernel = 5, kernel_dim=24, kernel_extent=24,
 #'                   min_value=1, preview = TRUE)
 #'}
-#'if(rayimage:::run_documentation()){
+#'if(run_documentation()){
 #'#Use a built-in kernel:
 #'render_convolution(dragon, kernel = generate_2d_exponential(falloff=2, dim=31, width=21),
 #'                   preview = TRUE)
 #'}
-#'if(rayimage:::run_documentation()){
+#'if(run_documentation()){
 #'#We can also apply this function to matrices:
 #'volcano |> image()
 #'volcano |>
 #'  render_convolution(kernel=generate_2d_gaussian(sd=1,dim=31)) |>
 #'  image()
 #'}
-#'if(rayimage:::run_documentation()){
+#'if(run_documentation()){
 #'#Use a custom kernel (in this case, an X shape):
 #'custom = diag(10) + (diag(10)[,10:1])
 #'plot_image(custom)
@@ -84,7 +87,7 @@ render_convolution = function(image, kernel = "gaussian",
     }
   }
   imagetype = get_file_type(image)
-  temp_image = image
+  # temp_image = ray_read_image(image)
   if(is.character(kernel)) {
     if(kernel == "gaussian") {
       kernel = generate_2d_gaussian(1,1,kernel_dim,kernel_extent)
@@ -105,13 +108,7 @@ render_convolution = function(image, kernel = "gaussian",
       kernel = newkernel
     }
   }
-  if(imagetype == "jpg") {
-    temp_image = suppressWarnings((jpeg::readJPEG(image)))
-  } else if (imagetype == "png"){
-    temp_image = suppressWarnings((png::readPNG(image)))
-  } else if (imagetype == "matrix") {
-    temp_image = t(image)
-  }
+  temp_image = ray_read_image(image, convert_to_array = FALSE)
 
   if(any(dim(kernel) > dim(temp_image)[1:2]*2 + 1)) {
     stop("kernel dimensions: ", paste0(dim(kernel),collapse="x"),
@@ -134,7 +131,7 @@ render_convolution = function(image, kernel = "gaussian",
   }
   temp_image_final = temp_image
   if(imagetype != "matrix") {
-    for(i in 1:(dim(temp_image)[3])) {
+    for(i in seq_len(dim(temp_image)[3])) {
       temp_image_final[,,i] = convolution_cpp(temp_image[,,i], kernel = kernel,
         progbar = progress, channel = i, bloom_matrix = bloom_matrix)
     }
@@ -150,19 +147,12 @@ render_convolution = function(image, kernel = "gaussian",
   }
   if(is.null(filename)) {
     if(preview) {
-      temp_image_final[temp_image_final > 1] = 1
-      temp_image_final[temp_image_final < 0] = 0
-      plot_image(temp_image_final)
+      plot_image(render_clamp(temp_image_final))
+      return(invisible(temp_image_final))
     } else {
-      if(imagetype == "matrix") {
-        t(temp_image_final)
-      } else {
-        temp_image_final
-      }
+      temp_image_final
     }
   } else {
-    temp_image_final[temp_image_final > 1] = 1
-    temp_image_final[temp_image_final < 0] = 0
-    save_png(temp_image_final,filename)
+    ray_write_image(render_clamp(temp_image_final),filename)
   }
 }
