@@ -21,49 +21,52 @@
 #'@return 3-layer RGB array of the processed image.
 #'@export
 #'@examples
-#'if(rayimage:::run_documentation()){
+#'if(run_documentation()){
 #'#Perform a convolution with the default gaussian kernel
 #'plot_image(dragon)
 #'}
-#'if(rayimage:::run_documentation()){
+#'if(run_documentation()){
 #'#Perform a convolution with the default gaussian kernel
 #'render_convolution_fft(dragon, kernel=0.1,preview = TRUE)
 #'}
-#'if(rayimage:::run_documentation()){
+#'if(run_documentation()){
 #'#Increase the width of the kernel
 #'render_convolution_fft(dragon, kernel = 2, kernel_dim=21,kernel_extent=6, preview = TRUE)
 #'}
-#'if(rayimage:::run_documentation()){
+#'if(run_documentation()){
 #'#Use a built-in kernel:
 #'render_convolution_fft(dragon, kernel = generate_2d_exponential(falloff=2, dim=31, width=21),
-#'                   preview = TRUE)
+#'                       preview = TRUE)
 #'}
-#'if(rayimage:::run_documentation()){
+#'if(run_documentation()){
 #'#Perform edge detection
 #'edge = matrix(c(-1,-1,-1,-1,8,-1,-1,-1,-1),3,3)
-#'render_convolution_fft(dragon, kernel = edge, preview = TRUE)
+#'render_convolution_fft(render_bw(dragon), kernel = edge, preview = TRUE)
 #'}
-#'if(rayimage:::run_documentation()){
+#'if(run_documentation()){
 #'#Perform edge detection with Sobel matrices
 #'sobel1 = matrix(c(1,2,1,0,0,0,-1,-2,-1),3,3)
 #'sobel2 = matrix(c(1,2,1,0,0,0,-1,-2,-1),3,3,byrow=TRUE)
-#'sob1 = render_convolution_fft(dragon, kernel = sobel1)
-#'sob2 = render_convolution_fft(dragon, kernel = sobel2)
+#'sob1 = render_convolution_fft(render_bw(dragon), kernel = sobel1)
+#'sob2 = render_convolution_fft(render_bw(dragon), kernel = sobel2)
 #'sob_all = sob1 + sob2
+#'plot_image(sob1)
+#'plot_image(sob2)
 #'plot_image(sob_all)
 #'}
-#'if(rayimage:::run_documentation()){
+#'if(run_documentation()){
 #'#We can also apply this function to matrices:
 #'volcano |> image()
 #'volcano |>
 #'  render_convolution_fft(kernel=generate_2d_gaussian(sd=1,dim=31)) |>
 #'  image()
 #'}
-#'if(rayimage:::run_documentation()){
-#'#Because this function uses the fast-fourier transform, large kernels will be much faster.
-#'render_convolution_fft(dragon, kernel = , preview = TRUE)
+#'if(run_documentation()){
+#'# Because this function uses the fast-fourier transform, large kernels will be much faster
+#'# than the same size kernels in `render_convolution()`
+#' render_convolution_fft(dragon, kernel_dim = c(200,200) , preview = TRUE)
 #'}
-#'if(rayimage:::run_documentation()){
+#'if(run_documentation()){
 #'#Use a custom kernel (in this case, an X shape):
 #'custom = diag(10) + (diag(10)[,10:1])
 #'#Normalize
@@ -104,16 +107,7 @@ render_convolution_fft = function(image, kernel = "gaussian",
       filename = paste0(filename,".png")
     }
   }
-  imagetype = get_file_type(image)
-  temp_image = image
-
-  if(imagetype == "jpg") {
-    temp_image = suppressWarnings((jpeg::readJPEG(image)))
-  } else if (imagetype == "png"){
-    temp_image = suppressWarnings((png::readPNG(image)))
-  } else if (imagetype == "matrix") {
-    temp_image = t(image)
-  }
+  temp_image = ray_read_image(image, convert_to_array = FALSE)
 
   if(is.character(kernel)) {
     if(kernel == "gaussian") {
@@ -175,19 +169,12 @@ render_convolution_fft = function(image, kernel = "gaussian",
   }
   if(is.null(filename)) {
     if(preview) {
-      vals[vals > 1] = 1
-      vals[vals < 0] = 0
-      plot_image(vals)
+      plot_image(render_clamp(vals))
+      return(invisible(vals))
     } else {
-      if(imagetype == "matrix") {
-        t(vals)
-      } else {
-        vals
-      }
+      vals
     }
   } else {
-    vals[vals > 1] = 1
-    vals[vals < 0] = 0
-    save_png(vals,filename)
+    ray_write_image(render_clamp(vals),filename)
   }
 }
